(function ($, Drupal, once) {
  Drupal.behaviors.docxToHtml = {
    attach: function (context, settings) {
      once('docxToHtml', '#document', context).forEach(function (element) {
        element.addEventListener("change", handleFileSelect, false);
      });

      once('docxToHtml', '#copy-button', context).forEach(function (element) {
        element.addEventListener('click', function (e) {
          e.preventDefault();
          copyToClipboard();
        });
      });

      function handleFileSelect(event) {
        readFileInputEventAsArrayBuffer(event, function(arrayBuffer) {
          mammoth.convertToHtml({ arrayBuffer: arrayBuffer })
            .then(displayResult)
            .catch(function(error) {
              console.error(error);
            });
        });
      }

      function displayResult(result) {
        $('#output', context).html(result.value);

        var messageHtml = result.messages.map(function(message) {
          return '<li class="' + message.type + '">' + escapeHtml(message.message) + '</li>';
        }).join("");

        $('#messages', context).html('<ul>' + messageHtml + '</ul>');
        $('#copy-button').show(); // Show the copy button after conversion
        $('#output').show(); // Show the output
      }

      function readFileInputEventAsArrayBuffer(event, callback) {
        var file = event.target.files[0];

        var reader = new FileReader();

        reader.onload = function(loadEvent) {
          var arrayBuffer = loadEvent.target.result;
          callback(arrayBuffer);
        };

        reader.readAsArrayBuffer(file);
      }

      function escapeHtml(value) {
        return value
          .replace(/&/g, '&amp;')
          .replace(/"//g, '&quot;')
          .replace(/</g, '&lt;')
          .replace(/>/g, '&gt;');
      }

      function copyToClipboard() {
        var outputElement = document.getElementById('output');
        var range = document.createRange();
        range.selectNodeContents(outputElement);
        var selection = window.getSelection();
        selection.removeAllRanges();
        selection.addRange(range);

        try {
          document.execCommand('copy');
          alert('HTML code copied to clipboard!');
        } catch (err) {
          alert('Unable to copy HTML code.');
        }
        
        // Remove the selection
        selection.removeAllRanges();
      }
    }
  };
})(jQuery, Drupal, once);
